import React, { useEffect, useState } from 'react';

import { getNoticeDetail } from '@/services/notice';

import { Modal, Timeline, Spin } from 'antd';

import { filterTimestamp } from '@/filters/index';

import './index.less';

type DetailModalProps = {
  id: string;
  DetailModalVisible: boolean;
  closeModal: () => void;
};

const DetailModal: React.FC<DetailModalProps> = ({ id, DetailModalVisible, closeModal }) => {
  const [detailData, setDetailData] = useState<Record<string, any>>({});

  // 加载等待样式、
  const [loading, setloading] = useState<boolean>(false);

  // 获取详情
  const GetNoticeDetail = async (): Promise<void> => {
    setloading(true);
    const { code, data } = await getNoticeDetail(id);
    setloading(false);
    if (code === 0) {
      console.log(data);
      setDetailData(data);
    }
  };

  useEffect(() => {
    GetNoticeDetail();
  }, []);
  return (
    <Modal visible={DetailModalVisible} title="查看详情" onOk={closeModal} onCancel={closeModal}>
      <Spin spinning={loading}>
        <Timeline>
          <Timeline.Item>
            <p>{detailData.label}</p> <p>{filterTimestamp(detailData.createTime)}</p>
          </Timeline.Item>
          <Timeline.Item>
            <p>公告内容</p>
            <div className="notice-container">
              <p
                style={{ listStyleType: 'decimal' }}
                dangerouslySetInnerHTML={{ __html: detailData.content }}
              ></p>
            </div>
          </Timeline.Item>
          <Timeline.Item>已有{detailData.readNum}人查看</Timeline.Item>
        </Timeline>
      </Spin>
    </Modal>
  );
};
export default DetailModal;
